==> KekikSpatula-0.4.4.tar.gz: KekikSpatula-0.4.4/README.md <==
# ✂️ KekikSpatula

[![Codacy Badge](https://app.codacy.com/project/badge/Grade/bc0a52a9b57f4c29930cbd6c796f9a8b)](https://www.codacy.com/gh/keyiflerolsun/KekikSpatula/dashboard?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=keyiflerolsun/KekikSpatula&amp;utm_campaign=Badge_Grade) ![Repo Boyutu](https://img.shields.io/github/repo-size/keyiflerolsun/KekikSpatula) ![Views](https://hits.seeyoufarm.com/api/count/incr/badge.svg?url=https://github.com/keyiflerolsun/KekikSpatula&title=Profile%20Views) [![Gitpod ready-to-code](https://img.shields.io/badge/Gitpod-ready--to--code-blue?logo=gitpod)](https://gitpod.io/#https://github.com/keyiflerolsun/KekikSpatula)

![PyPI - Python Version](https://img.shields.io/pypi/pyversions/KekikSpatula)
![PyPI - Status](https://img.shields.io/pypi/status/KekikSpatula)
![PyPI](https://img.shields.io/pypi/v/KekikSpatula)
![PyPI - Downloads](https://img.shields.io/pypi/dm/KekikSpatula)
![PyPI - Wheel](https://img.shields.io/pypi/wheel/KekikSpatula)
![PyPI - License](https://img.shields.io/pypi/l/KekikSpatula)

**Siz uğraşmayın diye** *biz uğraştık..* **~** `dızz 🐍`

[![forthebadge made-with-python](http://ForTheBadge.com/images/badges/made-with-python.svg)](https://www.python.org/)
[![ForTheBadge built-with-love](http://ForTheBadge.com/images/badges/built-with-love.svg)](https://GitHub.com/keyiflerolsun/)

## 🚀 Kurulum

```bash
# Yüklemek
pip install KekikSpatula

# Güncellemek
pip install -U KekikSpatula
```

## 📝 Aktif Spatulalar ve Kullanımları

- ⚕️ **[NobetciEczane](https://github.com/keyiflerolsun/KekikSpatula/blob/main/Testler/NobetciEczane.py)**
- ⛽️ **[Akaryakit](https://github.com/keyiflerolsun/KekikSpatula/blob/main/Testler/Akaryakit.py)**
- 💱 **[Doviz](https://github.com/keyiflerolsun/KekikSpatula/blob/main/Testler/Doviz.py)**
- 🌀 **[SonDepremler](https://github.com/keyiflerolsun/KekikSpatula/blob/main/Testler/SonDepremler.py)**
- 🛒 **[BimAktuel](https://github.com/keyiflerolsun/KekikSpatula/blob/main/Testler/BimAktuel.py)**
- 📰 **[SonDakika](https://github.com/keyiflerolsun/KekikSpatula/blob/main/Testler/SonDakika.py)**
- ☁️ **[HavaDurumu](https://github.com/keyiflerolsun/KekikSpatula/blob/main/Testler/HavaDurumu.py)**
- 🕌 **[Ezan](https://github.com/keyiflerolsun/KekikSpatula/blob/main/Testler/Ezan.py)**
- 📺 **[DiscUdemy](https://github.com/keyiflerolsun/KekikSpatula/blob/main/Testler/DiscUdemy.py)**
- ☢️ **[Covid](https://github.com/keyiflerolsun/KekikSpatula/blob/main/Testler/Covid.py)**
- ![Google](https://www.google.com/images/branding/googleg/1x/googleg_standard_color_16dp.png) **[Google](https://github.com/keyiflerolsun/KekikSpatula/blob/main/Testler/Google.py)**
- ![KekikTube](https://www.youtube.com/s/desktop/19da7d5c/img/favicon.ico) **[KekikTube](https://github.com/keyiflerolsun/KekikSpatula/blob/main/Testler/KekikTube.py)**
- ![UcuzUcak](https://i.imgur.com/YCcagvA.png) **[UcuzUcak](https://github.com/keyiflerolsun/KekikSpatula/blob/main/Testler/UcuzUcak.py)**
- ![CocukMasallari](https://i.imgur.com/cmIfRdM.png) **[CocukMasallari](https://github.com/keyiflerolsun/KekikSpatula/blob/main/Testler/CocukMasallari.py)**
- ![TrendyolUrun](https://www.trendyol.com/frontend/web/assets/images/favicon.ico) **[Trendyol](https://github.com/keyiflerolsun/KekikSpatula/blob/main/Testler/TrendyolUrun.py)**
- ![Sahibinden](https://i.imgur.com/XNI9phn.png) **[Sahibinden](https://github.com/keyiflerolsun/KekikSpatula/blob/main/Testler/Sahibinden.py)**
- ![TrendyolKategori](https://www.trendyol.com/frontend/web/assets/images/favicon.ico) **[Trendyol](https://github.com/keyiflerolsun/KekikSpatula/blob/main/Testler/TrendyolKategori.py)**

## 🌐 Telif Hakkı ve Lisans

* *Copyright (C) 2021 by* [keyiflerolsun](https://github.com/keyiflerolsun) ❤️️
* [GNU GENERAL PUBLIC LICENSE Version 3, 29 June 2007](https://github.com/keyiflerolsun/keyifUserBot/blob/master/LICENSE) *Koşullarına göre lisanslanmıştır..*

## ♻️ İletişim

*Benimle iletişime geçmek isterseniz, **Telegram**'dan mesaj göndermekten çekinmeyin;* [@keyiflerolsun](https://t.me/keyiflerolsun)

##

> **[@KekikAkademi](https://t.me/KekikAkademi)** *için yazılmıştır..*

==> KekikSpatula-0.4.8.tar.gz: KekikSpatula-0.4.8/README.md <==
# ✂️ KekikSpatula

[![Codacy Badge](https://app.codacy.com/project/badge/Grade/bc0a52a9b57f4c29930cbd6c796f9a8b)](https://www.codacy.com/gh/keyiflerolsun/KekikSpatula/dashboard?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=keyiflerolsun/KekikSpatula&amp;utm_campaign=Badge_Grade) ![Repo Boyutu](https://img.shields.io/github/repo-size/keyiflerolsun/KekikSpatula) ![Views](https://hits.seeyoufarm.com/api/count/incr/badge.svg?url=https://github.com/keyiflerolsun/KekikSpatula&title=Profile%20Views) [![Gitpod ready-to-code](https://img.shields.io/badge/Gitpod-ready--to--code-blue?logo=gitpod)](https://gitpod.io/#https://github.com/keyiflerolsun/KekikSpatula)

![PyPI - Python Version](https://img.shields.io/pypi/pyversions/KekikSpatula)
![PyPI - Status](https://img.shields.io/pypi/status/KekikSpatula)
![PyPI](https://img.shields.io/pypi/v/KekikSpatula)
![PyPI - Downloads](https://img.shields.io/pypi/dm/KekikSpatula)
![PyPI - Wheel](https://img.shields.io/pypi/wheel/KekikSpatula)
![PyPI - License](https://img.shields.io/pypi/l/KekikSpatula)

**Siz uğraşmayın diye** *biz uğraştık..* **~** `dızz 🐍`

[![forthebadge made-with-python](http://ForTheBadge.com/images/badges/made-with-python.svg)](https://www.python.org/)
[![ForTheBadge built-with-love](http://ForTheBadge.com/images/badges/built-with-love.svg)](https://GitHub.com/keyiflerolsun/)

## 🚀 Kurulum

```bash
# Yüklemek
pip install KekikSpatula

# Güncellemek
pip install -U KekikSpatula
```

## 📝 Aktif Spatulalar ve Kullanımları

- ⚕️ **[NobetciEczane](https://github.com/keyiflerolsun/KekikSpatula/blob/main/Testler/NobetciEczane.py)**
- ⛽️ **[Akaryakit](https://github.com/keyiflerolsun/KekikSpatula/blob/main/Testler/Akaryakit.py)**
- 💱 **[Doviz](https://github.com/keyiflerolsun/KekikSpatula/blob/main/Testler/Doviz.py)**
- 🌀 **[SonDepremler](https://github.com/keyiflerolsun/KekikSpatula/blob/main/Testler/SonDepremler.py)**
- 🛒 **[BimAktuel](https://github.com/keyiflerolsun/KekikSpatula/blob/main/Testler/BimAktuel.py)**
- 📰 **[SonDakika](https://github.com/keyiflerolsun/KekikSpatula/blob/main/Testler/SonDakika.py)**
- ☁️ **[HavaDurumu](https://github.com/keyiflerolsun/KekikSpatula/blob/main/Testler/HavaDurumu.py)**
- 🕌 **[Ezan](https://github.com/keyiflerolsun/KekikSpatula/blob/main/Testler/Ezan.py)**
- 📺 **[DiscUdemy](https://github.com/keyiflerolsun/KekikSpatula/blob/main/Testler/DiscUdemy.py)**
- ☢️ **[Covid](https://github.com/keyiflerolsun/KekikSpatula/blob/main/Testler/Covid.py)**
- ![Google](https://www.google.com/images/branding/googleg/1x/googleg_standard_color_16dp.png) **[Google](https://github.com/keyiflerolsun/KekikSpatula/blob/main/Testler/Google.py)**
- ![KekikTube](https://www.youtube.com/s/desktop/19da7d5c/img/favicon.ico) **[KekikTube](https://github.com/keyiflerolsun/KekikSpatula/blob/main/Testler/KekikTube.py)**
- ![UcuzUcak](https://i.imgur.com/YCcagvA.png) **[UcuzUcak](https://github.com/keyiflerolsun/KekikSpatula/blob/main/Testler/UcuzUcak.py)**
- ![CocukMasallari](https://i.imgur.com/cmIfRdM.png) **[CocukMasallari](https://github.com/keyiflerolsun/KekikSpatula/blob/main/Testler/CocukMasallari.py)**
- ![TrendyolUrun](https://www.trendyol.com/frontend/web/assets/images/favicon.ico) **[TrendyolUrun](https://github.com/keyiflerolsun/KekikSpatula/blob/main/Testler/TrendyolUrun.py)**
- ![Sahibinden](https://i.imgur.com/XNI9phn.png) **[Sahibinden](https://github.com/keyiflerolsun/KekikSpatula/blob/main/Testler/Sahibinden.py)**
- ![TrendyolKategori](https://www.trendyol.com/frontend/web/assets/images/favicon.ico) **[TrendyolKategori](https://github.com/keyiflerolsun/KekikSpatula/blob/main/Testler/TrendyolKategori.py)**
- ![ArasKargo](https://www.araskargo.com.tr/tr/images/favicon.ico) **[ArasKargo](https://github.com/keyiflerolsun/KekikSpatula/blob/main/Testler/ArasKargo.py)**

## 🌐 Telif Hakkı ve Lisans

* *Copyright (C) 2021 by* [keyiflerolsun](https://github.com/keyiflerolsun) ❤️️
* [GNU GENERAL PUBLIC LICENSE Version 3, 29 June 2007](https://github.com/keyiflerolsun/KekikSpatula/blob/main/LICENSE) *Koşullarına göre lisanslanmıştır..*

## ♻️ İletişim

*Benimle iletişime geçmek isterseniz, **Telegram**'dan mesaj göndermekten çekinmeyin;* [@keyiflerolsun](https://t.me/keyiflerolsun)

## 💸 Bağış Yap

**[☕️ Kahve Ismarla](https://KekikAkademi.org/Kahve)**

##

> **[@KekikAkademi](https://t.me/KekikAkademi)** *için yazılmıştır..*
